noZero <- ufs::noZero;

formatR <- formatR;

ifelseObj <- ufs::ifelseObj;

is.odd <- ufs::is.odd
is.even <- ufs::is.even

`%IN%` <- ufs::`%IN%`;

cat0 <- cat0;

isTrue <- ufs::isTrue;

is.nr <- ufs::is.nr;
